<?php

/**
 * Created by xDeveloper.
 * Site: http://www.xf-ar.com
 * Email: turkialawlqy@gmail.com
 * Date: 5/16/16,  11:42 AM
 */
class Turki_Ranks_Model_Ranks extends Turki_Package_Model
{
    protected $_table = 'xf_user_ranks';
    protected $_id = 'rank_minimum_level';

    public function insertUserRanksEntry($ranks, $rebuildCache = true)
    {
        $minimumLevel = intval($ranks['rank_minimum_level']);
        if ($minimumLevel < 0)
        {
            $minimumLevel = 0;
        }

        $existing = $this->_getDb()->fetchRow('
			SELECT rank_minimum_level
			FROM xf_user_ranks
			WHERE rank_minimum_level = ?
		', $minimumLevel);
        if ($existing)
        {
            throw new XenForo_Exception(new XenForo_Phrase('user_ranks_exists_x_points', array('count' => $minimumLevel)), true);
        }
        $this->_getDb()->insert('xf_user_ranks', array(
            'rank_minimum_level' => $minimumLevel,
            'rank' => utf8_substr($ranks['rank'], 0, 250),
            'rank_type' => $ranks['rank_type'],
            'ranklevel' => $ranks['ranklevel']
        ));

        if ($rebuildCache)
        {
            $this->rebuildUserRanksCache();
        }
    }


    public function updateUserRanks(array $titles, $rebuildCache = true)
    {
        $db = $this->_getDb();
        XenForo_Db::beginTransaction($db);

        $db->delete('xf_user_ranks');

        foreach ($titles AS $titleInfo)
        {
            if (isset($titleInfo['rank'], $titleInfo['rank_minimum_level']))
            {
                $this->insertUserRanksEntry($titleInfo, false);
            }
        }

        if ($rebuildCache)
        {
            $this->rebuildUserRanksCache();
        }

        XenForo_Db::commit($db);
    }

    public function deleteUserRankEntries(array $levels, $rebuildCache = true)
    {
        if (!$levels)
        {
            return;
        }

        $db = $this->_getDb();
        $db->delete('xf_user_ranks', 'rank_minimum_level IN (' . $db->quote($levels) . ')');

        if ($rebuildCache)
        {
            $this->rebuildUserRanksCache();
        }
    }
    public function rebuildUserRanksCache()
    {
        $titles = $this->getAll();
        $cache = array();
        foreach ($titles AS $title)
        {
            $cache[$title['rank_minimum_level']]['rank'] = $title['rank'];
            $cache[$title['rank_minimum_level']]['ranklevel'] = $title['ranklevel'];
            $cache[$title['rank_minimum_level']]['rank_type'] = $title['rank_type'];
        }
        krsort($cache, SORT_NUMERIC);
        XenForo_Application::setSimpleCacheData("userRanks", $cache);
        return $cache;
    }
}